@@ -275,15 +275,15 @@ format_statistics_caller <- function(x, cols, ...) {
 }
 
 arrange_statistics <- function(formated_statistics_result, split_cols, format_to,
-    Alias_mapping, blocks, indent_character) {
+    Alias_mapping, blocks, indent_character, indent) {
     formated_statistics_result <- replace_NA(formated_statistics_result)
 
-    return(arrange_helper(formated_statistics_result, split_cols, format_to, Alias_mapping, blocks, indent_character))
+    return(arrange_helper(formated_statistics_result, split_cols, format_to, Alias_mapping, blocks, indent_character, indent))
 }
 
 
 arrange_statistics_and_tests <- function(formated_statistics_result, formated_tests_result,
-    group_col, split_cols, format_to, Alias_mapping, blocks, indent_character) {
+    group_col, split_cols, format_to, Alias_mapping, blocks, indent_character, indent) {
     formated_statistics_result <- replace_NA(formated_statistics_result)
 
 
@@ -348,10 +348,11 @@ arrange_statistics_and_tests <- function(formated_statistics_result, formated_te
         })
 
 
-    return(arrange_helper(tabr, split_cols, format_to, Alias_mapping, blocks, indent_character))
+    return(arrange_helper(tabr, split_cols, format_to, Alias_mapping, blocks, indent_character, indent))
 }
 
-arrange_helper <- function(tab, split_cols, format_to, Alias_mapping, blocks, indent_character) {
+arrange_helper <- function(tab, split_cols, format_to, Alias_mapping, blocks, indent_character, indent) {
+
 
 
     # map cols and blocks to aliases
@@ -365,35 +366,41 @@ arrange_helper <- function(tab, split_cols, format_to, Alias_mapping, blocks, in
              warn_missing = FALSE)}
     else{blocks}
 
-    switch(format_to, Word = {
-      indent_character = if(is.null(indent_character)){atable_options("indent_character_Word")}else{indent_character}
 
-      tab <- indent_data_frame_helper(DD = tab,
-                                      split_cols = split_cols,
-                                      blocks = blocks,
-                                      indent_character = indent_character)
-      return(tab)
-    }, Latex = {
-      indent_character = if(is.null(indent_character)){atable_options("indent_character_Latex")}else{indent_character}
+
+    if(isTRUE(indent)){
+
+
+      switch(format_to, Word = {
+        indent_character = if(is.null(indent_character)){atable_options("indent_character_Word")}else{indent_character}
+
+        tab <- indent_data_frame_helper(DD = tab,
+                                        split_cols = split_cols,
+                                        blocks = blocks,
+                                        indent_character = indent_character)
+        return(tab)
+      }, Latex = {
+        indent_character = if(is.null(indent_character)){atable_options("indent_character_Latex")}else{indent_character}
 
         # the order is important: translate_to_LaTeX may change the colnames of tab. So
         # it is applied second.
         tab <- indent_data_frame_helper(DD = tab,
-                                       split_cols = split_cols,
-                                       blocks = blocks,
-                                       indent_character = indent_character)
+                                        split_cols = split_cols,
+                                        blocks = blocks,
+                                        indent_character = indent_character)
         tab <- translate_to_LaTeX(tab)
+
         return(tab)
-    }, HTML = {
-      indent_character = if(is.null(indent_character)){atable_options("indent_character_HTML")}else{indent_character}
+      }, HTML = {
+        indent_character = if(is.null(indent_character)){atable_options("indent_character_HTML")}else{indent_character}
 
         tab <- indent_data_frame_helper(DD = tab,
-                                       split_cols = split_cols,
-                                       blocks = blocks,
-                                       indent_character = indent_character)
+                                        split_cols = split_cols,
+                                        blocks = blocks,
+                                        indent_character = indent_character)
         return(tab)
-    }, Console = {
-      indent_character = if(is.null(indent_character)){atable_options("indent_character_Console")}else{indent_character}
+      }, Console = {
+        indent_character = if(is.null(indent_character)){atable_options("indent_character_Console")}else{indent_character}
 
         tab <- indent_data_frame_helper(DD = tab,
                                         split_cols = split_cols,
@@ -404,18 +411,24 @@ arrange_helper <- function(tab, split_cols, format_to, Alias_mapping, blocks, in
         class(tab) <- c("atable", class(tab))
 
         return(tab)
-    }, markdown = {
-      indent_character = if(is.null(indent_character)){atable_options("indent_character_markdown")}else{indent_character}
+      }, markdown = {
+        indent_character = if(is.null(indent_character)){atable_options("indent_character_markdown")}else{indent_character}
 
         tab <- indent_data_frame_helper(DD = tab,
                                         split_cols = split_cols,
                                         blocks = blocks,
                                         indent_character = indent_character)
         return(tab)
-    },
-    {
+      },
+      {
         stop("format_to ", format_to, " unknown.")
-    })
+      })
+
+    }else{
+      return(tab)}
+
+
+
 }
 
 #' @export
@@ -423,7 +436,7 @@ print.atable <- function(x, ...) print(as.data.frame(x), right = FALSE, ...)
 
 
 atable_splitted_grouped <- function(DD, target_cols, group_col, split_cols, format_to,
-    Alias_mapping, blocks, indent_character, ...) {
+    Alias_mapping, blocks, indent_character, indent, ...) {
 
     Observation_and_target_cols <- c(atable_options("colname_for_observations"),
         target_cols)
@@ -448,12 +461,12 @@ atable_splitted_grouped <- function(DD, target_cols, group_col, split_cols, form
 
 
     atable_result <- arrange_statistics_and_tests(formated_statistics_result, formated_tests_result,
-        group_col, split_cols, format_to, Alias_mapping, blocks, indent_character)
+        group_col, split_cols, format_to, Alias_mapping, blocks, indent_character, indent)
     return(atable_result)
 }
 
 atable_unsplitted_grouped <- function(DD, target_cols, group_col, split_cols, format_to,
-    Alias_mapping, blocks, indent_character, ...) {
+    Alias_mapping, blocks, indent_character, indent, ...) {
 
     Observation_and_target_cols <- c(atable_options("colname_for_observations"),
         target_cols)
@@ -476,11 +489,11 @@ atable_unsplitted_grouped <- function(DD, target_cols, group_col, split_cols, fo
         ...)
 
     atable_result <- arrange_statistics_and_tests(formated_statistics_result, formated_tests_result,
-        group_col, split_cols, format_to, Alias_mapping, blocks, indent_character)
+        group_col, split_cols, format_to, Alias_mapping, blocks, indent_character, indent)
     return(atable_result)
 }
 
-atable_splitted_ungrouped <- function(DD, target_cols, split_cols, format_to, Alias_mapping, blocks, indent_character,
+atable_splitted_ungrouped <- function(DD, target_cols, split_cols, format_to, Alias_mapping, blocks, indent_character, indent,
     ...) {
 
     Observation_and_target_cols <- c(atable_options("colname_for_observations"),
@@ -498,13 +511,13 @@ atable_splitted_ungrouped <- function(DD, target_cols, split_cols, format_to, Al
         cols = Observation_and_target_cols, ...)
 
     atable_result <- arrange_statistics(formated_statistics_result, split_cols, format_to,
-        Alias_mapping, blocks, indent_character)
+        Alias_mapping, blocks, indent_character, indent)
 
 
     return(atable_result)
 }
 
-atable_unsplitted_ungrouped <- function(DD, target_cols, format_to, Alias_mapping, blocks, indent_character,
+atable_unsplitted_ungrouped <- function(DD, target_cols, format_to, Alias_mapping, blocks, indent_character, indent,
     ...) {
 
     Observation_and_target_cols <- c(atable_options("colname_for_observations"),
@@ -526,7 +539,7 @@ atable_unsplitted_ungrouped <- function(DD, target_cols, format_to, Alias_mappin
     split_cols <- NULL  # i do not want to write another helper function.
     # Just use arrange_statistics, which uses split_cols.
     atable_result <- arrange_statistics(formated_statistics_result, split_cols, format_to,
-        Alias_mapping, blocks, indent_character)
+        Alias_mapping, blocks, indent_character, indent)
     return(atable_result)
 }
 
@@ -757,3 +770,191 @@ check_blocks <- function(blocks, target_cols)
   })
   return(TRUE)
 }
+
+
+
+format_compact_numeric = function(x,...)
+{
+
+  the_mean <- atable_options("format_numbers")(x$mean)
+  the_sd <- atable_options("format_numbers")(x$sd)
+
+  values <- c(Mean_SD = paste0(the_mean, " (", the_sd, ")") )
+
+  format_statistics_out <- data.frame(tag = factor("remove_me", levels = "remove_me"),
+                                      value = values, row.names = NULL, stringsAsFactors = FALSE, check.names = FALSE,
+                                      fix.empty.names = FALSE)
+
+  return(format_statistics_out)
+
+}
+
+
+format_compact_factor = function(x,...)
+{
+
+  nn <- names(x)
+
+  value <- unlist(x)
+  total <- sum(value)
+
+
+  percent <- 100 * value/total
+
+  if(length(nn)<=3){
+    # return only first level, ignore the others
+    # As atable::statistics.factor calls table(..., useNA='always'), there is always NA in nn and thus three
+    # levels are the minimum, not two levels
+    # The counts of missing values will not be displayed, but are included in the percent-calculation
+
+    value <- paste0(atable_options("format_percent")(percent[1]), "% (", atable_options("format_numbers")(value[1]), ")")
+
+
+    format_statistics_out <- data.frame(tag = factor(nn[1], levels = nn[1]), value = value[1],
+                                        row.names = NULL, stringsAsFactors = FALSE, check.names = FALSE, fix.empty.names = FALSE)
+
+    return(format_statistics_out)
+  }  else{
+
+
+    value <- paste0(atable_options("format_percent")(percent), "% (", atable_options("format_numbers")(value), ")")
+
+
+
+    format_statistics_out <- data.frame(tag = factor(nn, levels = nn),
+                                        value = value,
+                                        row.names = NULL, stringsAsFactors = FALSE, check.names = FALSE, fix.empty.names = FALSE)
+
+    return(format_statistics_out)
+  }
+}
+
+
+indent_tag_value = function(x, indent_character)
+{
+
+  stopifnot(
+    is.data.frame(x),
+    # all(sapply(x, is.character)),
+    nrow(x)>=1,
+    ncol(x)>=2
+  )
+
+  x[] = lapply(x, as.character)
+
+  index_variable = which(colnames(x) == atable_options("colname_for_variable") )
+  index_tag = which(colnames(x) == "tag")
+
+  stopifnot(index_variable>0,
+            index_tag==index_variable+1)
+
+  stopifnot(
+    is.character(indent_character),
+    length(indent_character)==1
+  )
+
+  # vorher:
+  # variable | tag
+  # nachher
+  # variable
+
+  if(nrow(x)==1)
+  {
+    # format_compact_numeric returns a data.frame wite nrow=1 and sets tag="remove_me"
+    # format_compact_factor may also return a data.frame wite nrow=1, but without tag="remove_me"
+
+    if(x$tag=="remove_me"){
+
+      out = x[-index_tag]
+      return(out)
+    }
+    else{
+      out = x[-index_variable]
+      colnames(out)[index_variable] = atable_options("colname_for_variable")
+      return(out)
+    }
+
+  }
+
+  # create an empty line an rbind it on top. Keep blocking-column if available.
+
+  empty_headline = x[1, -index_tag]
+  empty_headline[1,index_variable:ncol(empty_headline)]=NA
+  # set name of heading
+  empty_headline[1,index_variable] = x[1,index_variable]
+  # set block name of heading if available
+  empty_headline = if(atable_options("colname_for_blocks") %in% colnames(empty_headline))
+  {
+    empty_headline[[atable_options("colname_for_blocks") ]] = x[1, atable_options("colname_for_blocks") ]
+    empty_headline
+
+  }else{empty_headline}
+
+  indent = x
+  indent[ ,index_variable] = paste(indent_character, indent[,index_tag])
+  indent = indent[-index_tag]
+
+  out = rbind(empty_headline, indent,
+              stringsAsFactors = FALSE)
+
+  return(out)
+
+}
+
+fill_blocks = function(x)
+{
+  # replaces NA in a vector x with "no_blocking___1", "no_blocking___2", "no_blocking___3",...
+  # 1,2,3 counts the connected components of NA in x
+  # x=c(NA, NA, NA, "a","a", NA, NA, "b", "b", NA)
+  # fill_blocks(x)
+
+  block_prefix = "no_blocking___"
+  x
+  y=x
+  index=1
+
+  if(is.na(x[1])) {y[1] = paste0(block_prefix, index) }
+
+  for(i in 2:length(x))
+  {
+    if(is.na(x[i]) ){y[i] = paste0(block_prefix, index) }
+    else{
+      if(is.na(x[i-1])){index = index + 1}
+    }
+  }
+
+  return(y)
+}
+
+
+indent_blocks = function(DD, indent_character)
+{
+
+  stopifnot(colnames(DD)[1] == atable_options("colname_for_blocks"))
+
+  DD$block_name___ = fill_blocks(DD$block_name___)
+
+  DD$block_name___ = factor(DD$block_name___,
+                            levels = DD$block_name___[!duplicated(DD$block_name___)])
+
+
+
+  Block_indent = plyr::ddply(DD,
+                             atable_options("colname_for_blocks"),
+                             function(x){
+                               if( substr(x[[atable_options("colname_for_blocks")]][1] , 1,14) == "no_blocking___" )  {return(x)}
+                               empty = x[1, 2:ncol(x)]
+                               empty[1,1] = as.character(x[1,1])
+                               empty[1, 2:ncol(empty)]=NA
+
+                               x[,2] = paste(indent_character, x[,2])
+
+                               rbind(empty,
+                                     x[, 2:ncol(x)],
+                                     stringsAsFactors = FALSE)
+                             })
+
+  return(Block_indent[-1])
+
+
+}
